@@ -10,12 +10,12 @@
 #include "kwallet_interface.h"
 #include "kwalletmanager_debug.h"
 
-
-#include <KWallet>
-#include <QUrl>
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
+#include <KWallet>
 #include <QDragEnterEvent>
+#include <QUrl>
+#include <QVBoxLayout>
 
 KWalletManagerWidget::KWalletManagerWidget(QWidget *parent, Qt::WindowFlags /*flags*/):
     KPageWidget(parent)
@@ -208,4 +208,29 @@ bool KWalletManagerWidget::hasUnsavedChanges(const QString &name) const
     }
 }
 
+void KWalletManagerWidget::setErrorMessage(const QString &message) {
+    if (!_walletPages.isEmpty()) {
+        return;
+    }
+
+    if (_errorItem == nullptr) {
+        auto placeholderWidget = new QWidget();
+
+        auto layout = new QVBoxLayout();
+        placeholderWidget->setLayout(layout);
+
+        _errorLabel =
+            new QLabel(xi18nc("@info:status",
+                "An error occurred when connecting to the KWallet service:<nl/>%1",
+                message));
+        _errorLabel->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+        layout->addWidget(_errorLabel);
+
+        _errorItem = new KPageWidgetItem(placeholderWidget);
+    }
+
+    addPage(_errorItem);
+    setCurrentPage(_errorItem);
+}
+
 #include "moc_kwalletmanagerwidget.cpp"
